#[non_exhaustive]pub struct PostalAddress {
pub revision: i32,
pub region_code: String,
pub language_code: String,
pub postal_code: String,
pub sorting_code: String,
pub administrative_area: String,
pub locality: String,
pub sublocality: String,
pub address_lines: Vec<String>,
pub recipients: Vec<String>,
pub organization: String,
/* private fields */
}Expand description
Represents a postal address, such as for postal delivery or payments addresses. With a postal address, a postal service can deliver items to a premise, P.O. box, or similar. A postal address is not intended to model geographical locations like roads, towns, or mountains.
In typical usage, an address would be created by user input or from importing existing data, depending on the type of process.
Advice on address input or editing:
- Use an internationalization-ready address widget such as https://github.com/google/libaddressinput.
- Users should not be presented with UI elements for input or editing of fields outside countries where that field is used.
For more guidance on how to use this schema, see: https://support.google.com/business/answer/6397478.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.revision: i32The schema revision of the PostalAddress. This must be set to 0, which is
the latest revision.
All new revisions must be backward compatible with old revisions.
region_code: StringRequired. CLDR region code of the country/region of the address. This is never inferred and it is up to the user to ensure the value is correct. See https://cldr.unicode.org/ and https://www.unicode.org/cldr/charts/30/supplemental/territory_information.html for details. Example: “CH” for Switzerland.
language_code: StringOptional. BCP-47 language code of the contents of this address (if known). This is often the UI language of the input form or is expected to match one of the languages used in the address’ country/region, or their transliterated equivalents. This can affect formatting in certain countries, but is not critical to the correctness of the data and will never affect any validation or other non-formatting related operations.
If this value is not known, it should be omitted (rather than specifying a possibly incorrect default).
Examples: “zh-Hant”, “ja”, “ja-Latn”, “en”.
postal_code: StringOptional. Postal code of the address. Not all countries use or require postal codes to be present, but where they are used, they may trigger additional validation with other parts of the address (for example, state or zip code validation in the United States).
sorting_code: StringOptional. Additional, country-specific, sorting code. This is not used in most regions. Where it is used, the value is either a string like “CEDEX”, optionally followed by a number (for example, “CEDEX 7”), or just a number alone, representing the “sector code” (Jamaica), “delivery area indicator” (Malawi) or “post office indicator” (Côte d’Ivoire).
administrative_area: StringOptional. Highest administrative subdivision which is used for postal addresses of a country or region. For example, this can be a state, a province, an oblast, or a prefecture. For Spain, this is the province and not the autonomous community (for example, “Barcelona” and not “Catalonia”). Many countries don’t use an administrative area in postal addresses. For example, in Switzerland, this should be left unpopulated.
locality: StringOptional. Generally refers to the city or town portion of the address.
Examples: US city, IT comune, UK post town.
In regions of the world where localities are not well defined or do not fit
into this structure well, leave locality empty and use address_lines.
sublocality: StringOptional. Sublocality of the address. For example, this can be a neighborhood, borough, or district.
address_lines: Vec<String>Unstructured address lines describing the lower levels of an address.
Because values in address_lines do not have type information and may
sometimes contain multiple values in a single field (for example,
“Austin, TX”), it is important that the line order is clear. The order of
address lines should be “envelope order” for the country or region of the
address. In places where this can vary (for example, Japan),
address_language is used to make it explicit (for example, “ja” for
large-to-small ordering and “ja-Latn” or “en” for small-to-large). In this
way, the most specific line of an address can be selected based on the
language.
The minimum permitted structural representation of an address consists
of a region_code with all remaining information placed in the
address_lines. It would be possible to format such an address very
approximately without geocoding, but no semantic reasoning could be
made about any of the address components until it was at least
partially resolved.
Creating an address only containing a region_code and address_lines and
then geocoding is the recommended way to handle completely unstructured
addresses (as opposed to guessing which parts of the address should be
localities or administrative areas).
recipients: Vec<String>Optional. The recipient at the address. This field may, under certain circumstances, contain multiline information. For example, it might contain “care of” information.
organization: StringOptional. The name of the organization at the address.
Implementations
Sourceimpl PostalAddress
impl PostalAddress
pub fn new() -> Self
Sourcepub fn set_revision<T: Into<i32>>(self, v: T) -> Self
pub fn set_revision<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_region_code<T: Into<String>>(self, v: T) -> Self
pub fn set_region_code<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_language_code<T: Into<String>>(self, v: T) -> Self
pub fn set_language_code<T: Into<String>>(self, v: T) -> Self
Sets the value of language_code.
Example
let x = PostalAddress::new().set_language_code("example");Sourcepub fn set_postal_code<T: Into<String>>(self, v: T) -> Self
pub fn set_postal_code<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_sorting_code<T: Into<String>>(self, v: T) -> Self
pub fn set_sorting_code<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_administrative_area<T: Into<String>>(self, v: T) -> Self
pub fn set_administrative_area<T: Into<String>>(self, v: T) -> Self
Sets the value of administrative_area.
Example
let x = PostalAddress::new().set_administrative_area("example");Sourcepub fn set_locality<T: Into<String>>(self, v: T) -> Self
pub fn set_locality<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_sublocality<T: Into<String>>(self, v: T) -> Self
pub fn set_sublocality<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_address_lines<T, V>(self, v: T) -> Self
pub fn set_address_lines<T, V>(self, v: T) -> Self
Sets the value of address_lines.
Example
let x = PostalAddress::new().set_address_lines(["a", "b", "c"]);Sourcepub fn set_recipients<T, V>(self, v: T) -> Self
pub fn set_recipients<T, V>(self, v: T) -> Self
Sets the value of recipients.
Example
let x = PostalAddress::new().set_recipients(["a", "b", "c"]);Sourcepub fn set_organization<T: Into<String>>(self, v: T) -> Self
pub fn set_organization<T: Into<String>>(self, v: T) -> Self